@@ -52,10 +52,12 @@ def fzfsearch(entry: str, addr: int) -> None:  # will receive two calls by 'pz'
 
 
 def list_directory(entry: str, addr: int) -> None:
-    entry = entry.removeprefix('Microsoft.PowerShell.Core\\FileSystem::')
-    params = entry.split(';')
-    ls = Ls(*params, to_cache=True)
+    opt, path = entry.split(';')
+    path = path.removeprefix('Microsoft.PowerShell.Core\\FileSystem::')
+
+    ls = Ls(opt, path, to_cache=True)
     ls.echo(0)
+
     sock.sendto(ls.out.data.encode(), addr)
 
 
